==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/services/logs/CfnQueryDefinitionProps.java <==
package software.amazon.awscdk.services.logs;

/**
 * Properties for defining a `AWS::Logs::QueryDefinition`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:24:35.523Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_logs.CfnQueryDefinitionProps")
@software.amazon.jsii.Jsii.Proxy(CfnQueryDefinitionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnQueryDefinitionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Logs::QueryDefinition.Name`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * `AWS::Logs::QueryDefinition.QueryString`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getQueryString();

    /**
     * `AWS::Logs::QueryDefinition.LogGroupNames`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getLogGroupNames() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnQueryDefinitionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnQueryDefinitionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnQueryDefinitionProps> {
        private java.lang.String name;
        private java.lang.String queryString;
        private java.util.List<java.lang.String> logGroupNames;

        /**
         * Sets the value of {@link CfnQueryDefinitionProps#getName}
         * @param name `AWS::Logs::QueryDefinition.Name`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnQueryDefinitionProps#getQueryString}
         * @param queryString `AWS::Logs::QueryDefinition.QueryString`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryString(java.lang.String queryString) {
            this.queryString = queryString;
            return this;
        }

        /**
         * Sets the value of {@link CfnQueryDefinitionProps#getLogGroupNames}
         * @param logGroupNames `AWS::Logs::QueryDefinition.LogGroupNames`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logGroupNames(java.util.List<java.lang.String> logGroupNames) {
            this.logGroupNames = logGroupNames;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnQueryDefinitionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnQueryDefinitionProps build() {
            return new Jsii$Proxy(name, queryString, logGroupNames);
        }
    }

    /**
     * An implementation for {@link CfnQueryDefinitionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnQueryDefinitionProps {
        private final java.lang.String name;
        private final java.lang.String queryString;
        private final java.util.List<java.lang.String> logGroupNames;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.queryString = software.amazon.jsii.Kernel.get(this, "queryString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.logGroupNames = software.amazon.jsii.Kernel.get(this, "logGroupNames", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String name, final java.lang.String queryString, final java.util.List<java.lang.String> logGroupNames) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.name = java.util.Objects.requireNonNull(name, "name is required");
            this.queryString = java.util.Objects.requireNonNull(queryString, "queryString is required");
            this.logGroupNames = logGroupNames;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.String getQueryString() {
            return this.queryString;
        }

        @Override
        public final java.util.List<java.lang.String> getLogGroupNames() {
            return this.logGroupNames;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("name", om.valueToTree(this.getName()));
            data.set("queryString", om.valueToTree(this.getQueryString()));
            if (this.getLogGroupNames() != null) {
                data.set("logGroupNames", om.valueToTree(this.getLogGroupNames()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_logs.CfnQueryDefinitionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnQueryDefinitionProps.Jsii$Proxy that = (CfnQueryDefinitionProps.Jsii$Proxy) o;

            if (!name.equals(that.name)) return false;
            if (!queryString.equals(that.queryString)) return false;
            return this.logGroupNames != null ? this.logGroupNames.equals(that.logGroupNames) : that.logGroupNames == null;
        }

        @Override
        public final int hashCode() {
            int result = this.name.hashCode();
            result = 31 * result + (this.queryString.hashCode());
            result = 31 * result + (this.logGroupNames != null ? this.logGroupNames.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/logs/CfnQueryDefinitionProps.java <==
package software.amazon.awscdk.services.logs;

/**
 * Properties for defining a `CfnQueryDefinition`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.logs.*;
 * CfnQueryDefinitionProps cfnQueryDefinitionProps = CfnQueryDefinitionProps.builder()
 *         .name("name")
 *         .queryString("queryString")
 *         // the properties below are optional
 *         .logGroupNames(List.of("logGroupNames"))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:11.460Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_logs.CfnQueryDefinitionProps")
@software.amazon.jsii.Jsii.Proxy(CfnQueryDefinitionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnQueryDefinitionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * A name for the query definition.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * The query string to use for this query definition.
     * <p>
     * For more information, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html">CloudWatch Logs Insights Query Syntax</a> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getQueryString();

    /**
     * Use this parameter if you want the query to query only certain log groups.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getLogGroupNames() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnQueryDefinitionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnQueryDefinitionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnQueryDefinitionProps> {
        java.lang.String name;
        java.lang.String queryString;
        java.util.List<java.lang.String> logGroupNames;

        /**
         * Sets the value of {@link CfnQueryDefinitionProps#getName}
         * @param name A name for the query definition. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnQueryDefinitionProps#getQueryString}
         * @param queryString The query string to use for this query definition. This parameter is required.
         *                    For more information, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html">CloudWatch Logs Insights Query Syntax</a> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryString(java.lang.String queryString) {
            this.queryString = queryString;
            return this;
        }

        /**
         * Sets the value of {@link CfnQueryDefinitionProps#getLogGroupNames}
         * @param logGroupNames Use this parameter if you want the query to query only certain log groups.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logGroupNames(java.util.List<java.lang.String> logGroupNames) {
            this.logGroupNames = logGroupNames;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnQueryDefinitionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnQueryDefinitionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnQueryDefinitionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnQueryDefinitionProps {
        private final java.lang.String name;
        private final java.lang.String queryString;
        private final java.util.List<java.lang.String> logGroupNames;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.queryString = software.amazon.jsii.Kernel.get(this, "queryString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.logGroupNames = software.amazon.jsii.Kernel.get(this, "logGroupNames", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.queryString = java.util.Objects.requireNonNull(builder.queryString, "queryString is required");
            this.logGroupNames = builder.logGroupNames;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.String getQueryString() {
            return this.queryString;
        }

        @Override
        public final java.util.List<java.lang.String> getLogGroupNames() {
            return this.logGroupNames;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("name", om.valueToTree(this.getName()));
            data.set("queryString", om.valueToTree(this.getQueryString()));
            if (this.getLogGroupNames() != null) {
                data.set("logGroupNames", om.valueToTree(this.getLogGroupNames()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_logs.CfnQueryDefinitionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnQueryDefinitionProps.Jsii$Proxy that = (CfnQueryDefinitionProps.Jsii$Proxy) o;

            if (!name.equals(that.name)) return false;
            if (!queryString.equals(that.queryString)) return false;
            return this.logGroupNames != null ? this.logGroupNames.equals(that.logGroupNames) : that.logGroupNames == null;
        }

        @Override
        public final int hashCode() {
            int result = this.name.hashCode();
            result = 31 * result + (this.queryString.hashCode());
            result = 31 * result + (this.logGroupNames != null ? this.logGroupNames.hashCode() : 0);
            return result;
        }
    }
}
